*************
pyparsing API
*************

.. automodule:: pyparsing
    :members:
    :special-members: __add__,__sub__,__div__,__mul__,__and__,__or__,__xor__,__lshift__,__invert__,__call__,__getitem__,__str__
    :exclude-members: __init__,__repl__,parseImpl,parseImpl_regex,parseImplAsGroupList,parseImplAsMatch,postParse,preParse

Module ``pyparsing.diagram``
----------------------------

.. automodule:: pyparsing.diagram
   :members:

.. 'hidden' prevents the toctree from appearing at the bottom of the page

.. toctree::
   :maxdepth: 2
   :hidden:

   self
